# coding: utf-8

"""
    Datový konektor Domino pro eSMLOUVY

    Toto je datový konektor umožňující datovou výměnu mezi obchodní logikou aplikace eSMLOUVY a datovým serverem HCL Domino.  Ovládá se pomocí REST API   # noqa: E501

    OpenAPI spec version: 1.1.0
    Contact: info@sysnet.cz
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import esmlouvy_connector
from esmlouvy_connector.api.attachments_api import AttachmentsApi  # noqa: E501
from esmlouvy_connector.rest import ApiException


class TestAttachmentsApi(unittest.TestCase):
    """AttachmentsApi unit test stubs"""

    def setUp(self):
        self.api = AttachmentsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_delete_attachment(self):
        """Test case for delete_attachment

        odstraní přílohu i s metadaty  # noqa: E501
        """
        pass

    def test_get_attachment(self):
        """Test case for get_attachment

        vrací soubor přílohy  # noqa: E501
        """
        pass

    def test_get_attachment_list(self):
        """Test case for get_attachment_list

        získá seznam příloh  # noqa: E501
        """
        pass

    def test_get_attachment_list_container(self):
        """Test case for get_attachment_list_container

        vrací seznam příloh v kontejneru  # noqa: E501
        """
        pass

    def test_get_attachment_list_document(self):
        """Test case for get_attachment_list_document

        vrací seznam příloh v dokumentu  # noqa: E501
        """
        pass

    def test_get_attachment_metadata(self):
        """Test case for get_attachment_metadata

        vrací metadata přílohy  # noqa: E501
        """
        pass

    def test_post_attachment(self):
        """Test case for post_attachment

        uploaduje novou přílohu (Crud)  # noqa: E501
        """
        pass

    def test_put_attachment(self):
        """Test case for put_attachment

        aktualizuje metadata přílohy  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
