# coding: utf-8

"""
    Datový konektor Domino pro eSMLOUVY

    Toto je datový konektor umožňující datovou výměnu mezi obchodní logikou aplikace eSMLOUVY a datovým serverem HCL Domino.  Ovládá se pomocí REST API   # noqa: E501

    OpenAPI spec version: 1.1.0
    Contact: info@sysnet.cz
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import esmlouvy_connector
from esmlouvy_connector.models.document_workflow import DocumentWorkflow  # noqa: E501
from esmlouvy_connector.rest import ApiException


class TestDocumentWorkflow(unittest.TestCase):
    """DocumentWorkflow unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testDocumentWorkflow(self):
        """Test DocumentWorkflow"""
        # FIXME: construct object with mandatory attributes with example values
        # model = esmlouvy_connector.models.document_workflow.DocumentWorkflow()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
