# coding: utf-8

"""
    Datový konektor Domino pro eSMLOUVY

    Toto je datový konektor umožňující datovou výměnu mezi obchodní logikou aplikace eSMLOUVY a datovým serverem HCL Domino.  Ovládá se pomocí REST API   # noqa: E501

    OpenAPI spec version: 1.1.0
    Contact: info@sysnet.cz
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import esmlouvy_connector
from esmlouvy_connector.api.public_api import PublicApi  # noqa: E501
from esmlouvy_connector.rest import ApiException


class TestPublicApi(unittest.TestCase):
    """PublicApi unit test stubs"""

    def setUp(self):
        self.api = PublicApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_delete_budget_category(self):
        """Test case for delete_budget_category

        odstraní položku rozpočtového zařazení s daným identifikátorem (cruD)  # noqa: E501
        """
        pass

    def test_delete_container(self):
        """Test case for delete_container

        odstraní dokumentový kontejner s daným identifikátorem (cruD)  # noqa: E501
        """
        pass

    def test_delete_cover(self):
        """Test case for delete_cover

        odstraní krycí list s daným identifikátorem (cruD)  # noqa: E501
        """
        pass

    def test_delete_payment_event(self):
        """Test case for delete_payment_event

        odstraní položku platebního kalenáře s daným identifikátorem (cruD)  # noqa: E501
        """
        pass

    def test_delete_registration(self):
        """Test case for delete_registration

        odstraní evidenční list s daným identifikátorem (cruD)  # noqa: E501
        """
        pass

    def test_delete_standpoint(self):
        """Test case for delete_standpoint

        odstraní stanovisko s daným identifikátorem (cruD)  # noqa: E501
        """
        pass

    def test_get_budget_category(self):
        """Test case for get_budget_category

        vrací položku rozpočtového zařazení s daným identifikátorem (cRud)  # noqa: E501
        """
        pass

    def test_get_budget_category_list(self):
        """Test case for get_budget_category_list

        vrací seznam rozpočtových zařazení  # noqa: E501
        """
        pass

    def test_get_budget_category_list_by_dept(self):
        """Test case for get_budget_category_list_by_dept

        vrací všechna rozpočtová opatření pro útvar  # noqa: E501
        """
        pass

    def test_get_container(self):
        """Test case for get_container

        vrací dokumentový kontejner s daným identifikátorem (cRud)  # noqa: E501
        """
        pass

    def test_get_container_content(self):
        """Test case for get_container_content

        vrací obsah kontejneru s daným identifikátorem  # noqa: E501
        """
        pass

    def test_get_container_list(self):
        """Test case for get_container_list

        vrací seznam dokumentových kontejnerů  # noqa: E501
        """
        pass

    def test_get_cover(self):
        """Test case for get_cover

        vrací krycí list s daným identifikátorem (cRud)  # noqa: E501
        """
        pass

    def test_get_cover_list(self):
        """Test case for get_cover_list

        vrací seznam kycích listů  # noqa: E501
        """
        pass

    def test_get_cover_list_container(self):
        """Test case for get_cover_list_container

        vrací seznam kycích listů v kontejneru  # noqa: E501
        """
        pass

    def test_get_payment_event(self):
        """Test case for get_payment_event

        vrací položku platebního kalenáře s daným identifikátorem (cRud)  # noqa: E501
        """
        pass

    def test_get_payment_event_list(self):
        """Test case for get_payment_event_list

        vrací seznam položek platebního kalendáře  # noqa: E501
        """
        pass

    def test_get_payment_event_list_parent(self):
        """Test case for get_payment_event_list_parent

        vrací seznam položek platebního kalendáře pro nadřazený dokument  # noqa: E501
        """
        pass

    def test_get_registration(self):
        """Test case for get_registration

        vrací evidenční list s daným identifikátorem (cRud)  # noqa: E501
        """
        pass

    def test_get_registration_list(self):
        """Test case for get_registration_list

        vrací seznam registračních listů  # noqa: E501
        """
        pass

    def test_get_registration_list_container(self):
        """Test case for get_registration_list_container

        vrací seznam registračních listů v kontejneru  # noqa: E501
        """
        pass

    def test_get_standpoint(self):
        """Test case for get_standpoint

        vrací stanovisko s daným identifikátorem (cRud)  # noqa: E501
        """
        pass

    def test_get_standpoint_list(self):
        """Test case for get_standpoint_list

        vrací seznam stanovisek  # noqa: E501
        """
        pass

    def test_get_standpoint_list_container(self):
        """Test case for get_standpoint_list_container

        vrací seznam stanovisek v kontejneru  # noqa: E501
        """
        pass

    def test_get_standpoint_list_parent(self):
        """Test case for get_standpoint_list_parent

        vrací seznam stanovisek pro nadřízený dokument  # noqa: E501
        """
        pass

    def test_post_budget_category(self):
        """Test case for post_budget_category

        vytvoří novou položku rozpočtového zařazení (Crud)  # noqa: E501
        """
        pass

    def test_post_container(self):
        """Test case for post_container

        vytvoří nový dokumentový kontejner (Crud)  # noqa: E501
        """
        pass

    def test_post_cover(self):
        """Test case for post_cover

        vytvoří nový krycí list (Crud)  # noqa: E501
        """
        pass

    def test_post_payment_event(self):
        """Test case for post_payment_event

        vytvoří novou položku platebního kalendáře (Crud)  # noqa: E501
        """
        pass

    def test_post_registration(self):
        """Test case for post_registration

        vytvoří nový evidenční list (Crud)  # noqa: E501
        """
        pass

    def test_post_standpoint(self):
        """Test case for post_standpoint

        vytvoří nové stanovisko (Crud)  # noqa: E501
        """
        pass

    def test_put_budget_category(self):
        """Test case for put_budget_category

        aktualizuje položku rozpočtového zařazení s daným identifikátorem (crUd)  # noqa: E501
        """
        pass

    def test_put_container(self):
        """Test case for put_container

        aktualizuje dokumentový kontejner s daným identifikátorem (crUd)  # noqa: E501
        """
        pass

    def test_put_cover(self):
        """Test case for put_cover

        aktualizuje krycí list s daným identifikátorem (crUd)  # noqa: E501
        """
        pass

    def test_put_payment_event(self):
        """Test case for put_payment_event

        aktualizuje položku platebního kalenáře s daným identifikátorem (crUd)  # noqa: E501
        """
        pass

    def test_put_registration(self):
        """Test case for put_registration

        aktualizuje evidenční list s daným identifikátorem (crUd)  # noqa: E501
        """
        pass

    def test_put_standpoint(self):
        """Test case for put_standpoint

        aktualizuje stanovisko s daným identifikátorem (crUd)  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
