# coding: utf-8

"""
    Datový konektor Domino pro eSMLOUVY

    Toto je datový konektor umožňující datovou výměnu mezi obchodní logikou aplikace eSMLOUVY a datovým serverem HCL Domino.  Ovládá se pomocí REST API   # noqa: E501

    OpenAPI spec version: 1.1.0
    Contact: info@sysnet.cz
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import esmlouvy_connector
from esmlouvy_connector.api.admins_api import AdminsApi  # noqa: E501
from esmlouvy_connector.rest import ApiException


class TestAdminsApi(unittest.TestCase):
    """AdminsApi unit test stubs"""

    def setUp(self):
        self.api = AdminsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_get_config(self):
        """Test case for get_config

        získá konfiguraci konektoru  # noqa: E501
        """
        pass

    def test_get_profile(self):
        """Test case for get_profile

        získá konfiguraci databáze serveru Domino  # noqa: E501
        """
        pass

    def test_get_profile_dir(self):
        """Test case for get_profile_dir

        získá pomocný profil (řízené slovníky) konfigurace databáze serveru Domino  # noqa: E501
        """
        pass

    def test_get_profile_roles(self):
        """Test case for get_profile_roles

        získá pomocný profil (role) konfigurace databáze serveru Domino  # noqa: E501
        """
        pass

    def test_put_config(self):
        """Test case for put_config

        aktualizuje hlavní konfiguraci konektoru  # noqa: E501
        """
        pass

    def test_put_profile(self):
        """Test case for put_profile

        aktualizuje nebo vytvoří hlavní konfiguraci aplikace Domino  # noqa: E501
        """
        pass

    def test_put_profile_dir(self):
        """Test case for put_profile_dir

        aktualizuje nebo vytvoří pomocný profil (řízené slovníky) konfigurace databáze serveru Domino  # noqa: E501
        """
        pass

    def test_put_profile_roles(self):
        """Test case for put_profile_roles

        aktualizuje nebo vytvoří pomocný profil (role) konfigurace databáze serveru Domino  # noqa: E501
        """
        pass

    def test_replace_name(self):
        """Test case for replace_name

        Zamění jméno ve všech dokumentech a polích, kde se vyskytuje  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
